<?php namespace Site21\PartnersPrices;

use Event;
use System\Classes\PluginBase;
use Site21\PartnersPrices\Classes\Event\Offer\ExtendOfferFieldsHandler;
use Site21\PartnersPrices\Classes\Event\Offer\ExtendOfferModel;
use Site21\PartnersPrices\Classes\Event\Offer\ExtendOfferCollection;
use Config;
use Illuminate\Foundation\AliasLoader;
use phpQuery;
use Lovata\Shopaholic\Models\Offer;
use Flash;
use Lovata\Shopaholic\Controllers\Products;
use Lovata\Shopaholic\Classes\Collection\OfferCollection;
use Artisan;

/**
 * PartnersPrices Plugin Information File
 */
class Plugin extends PluginBase
{
    public function pluginDetails()
    {
        return [
            'name'        => 'PartnersPrices',
            'description' => 'Обновление партнерских цен',
            'author'      => 'Site21',
            'icon'        => 'icon-leaf'
        ];
    }


    public function register()
    {

    }


    public function boot()
    {
        Event::subscribe(ExtendOfferFieldsHandler::class);
        Event::subscribe(ExtendOfferModel::class);
        Event::subscribe(ExtendOfferCollection::class);
        $this->bootPackages();

        // Добавляем кнопку Обновления цен
        Event::listen('lovata.backend.extend_list_toolbar', function($controller) {
            if (!$controller instanceof \Lovata\Shopaholic\Controllers\Products) {
                return;
            }
            return $controller->makePartial('$/site21/partnersprices/partials/_extended_toolbar.htm');
        });
        Products::extend(function($controller){
            $controller->addDynamicMethod('onImportPricesFromPartners', function () {
                $offers = OfferCollection::make()->withPartnerLink();
                foreach($offers as $offer) {
                    if($offer->partner_link) {
                        $html  = file_get_contents($offer->partner_link);
                        if($html) {
                            $doc = phpQuery::newDocumentHTML($html);
                            if(strpos($offer->partner_link, 'adgm.ru')) {
                                $price = $doc->find('#price .product-card__current-price')->text();
                            } else {
                                return;
                            }
                            
                            $model = Offer::find($offer->id);
                            $model->price = $price;
                            $model->save();
                        }
                    }
                }
                Flash::info('Цены успешно обновились. Файл яндекс маркета обновлён.');
            });
        });
    }


    public function registerPermissions()
    {
        return []; // Remove this line to activate

        return [
            'site21.partnersprices.some_permission' => [
                'tab' => 'PartnersPrices',
                'label' => 'Some permission'
            ],
        ];
    }

    public function bootPackages() {
        // Get the namespace of the current plugin to use in accessing the Config of the plugin
        $pluginNamespace = str_replace('\\', '.', strtolower(__NAMESPACE__));
        
        // Instantiate the AliasLoader for any aliases that will be loaded
        $aliasLoader = AliasLoader::getInstance();
        
        // Get the packages to boot
        $packages = Config::get($pluginNamespace . '::packages');
        
        // Boot each package
        foreach ($packages as $name => $options) {
            // Setup the configuration for the package, pulling from this plugin's config
            if (!empty($options['config']) && !empty($options['config_namespace'])) {
                Config::set($options['config_namespace'], $options['config']);
            }
            
            // Register any Service Providers for the package
            if (!empty($options['providers'])) {
                foreach ($options['providers'] as $provider) {
                    App::register($provider);
                }
            }
            
            // Register any Aliases for the package
            if (!empty($options['aliases'])) {
                foreach ($options['aliases'] as $alias => $path) {
                    $aliasLoader->alias($alias, $path);
                }
            }
        }
    }
}
